
BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    require Test::More;
    Test::More::plan(skip_all => 'these tests are for testing by the author');
  }
}

use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.006008
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
DROLSKY
DROLSKY's
Rolsky
Rolsky's
API
CPAN
GLOBREF
OO
PayPal
SCALARREF
ValidatePos
baz
onwards
pre
runtime
Dave
autarch
Ilya
Martynov
ilya
and
Mash
jmash
Olivier
Mengué
dolmen
lib
Attribute
Params
Validate
Constants
PP
XS
ValidatePP
ValidateXS
